@@ -1,4 +1,5 @@
 import collections
+import collections.abc
 import ipaddress
 import re
 
@@ -119,7 +120,7 @@ class SplitResult(collections.namedtuple('SplitResult', _URI_COMPONENTS)):
         # TBD: (userinfo, host, port) kwargs, default string?
         if default is None:
             default = (None, None, None)
-        elif not isinstance(default, collections.Iterable):
+        elif not isinstance(default, collections.abc.Iterable):
             raise TypeError('Invalid default type')
         elif len(default) != 3:
             raise ValueError('Invalid default length')
@@ -345,7 +346,7 @@ class SplitResultBytes(SplitResult):
     DIGITS = b'0123456789'
 
 
-class SplitResultUnicode(SplitResult):
+class SplitResultString(SplitResult):
 
     __slots__ = ()  # prevent creation of instance dictionary
 
@@ -381,7 +382,7 @@ def urisplit(uristring):
     if isinstance(uristring, bytes):
         result = SplitResultBytes
     else:
-        result = SplitResultUnicode
+        result = SplitResultString
     return result(*result.RE.match(uristring).groups())
 
 
@@ -394,5 +395,5 @@ def uriunsplit(parts):
     if isinstance(path, bytes):
         result = SplitResultBytes
     else:
-        result = SplitResultUnicode
+        result = SplitResultString
     return result(scheme, authority, path, query, fragment).geturi()
